@@ -7,22 +7,12 @@ use v5.10;
 use strict;
 use warnings;
 
-use parent 'Exporter';
+use Type::Library -base;
+use Type::Utils ();
 
-use Module::Runtime qw(use_module);
+our $VERSION = '0.02';
 
-our $VERSION = '0.01';
-
-my @types;
-
-for my $mod ( qw/Types::OTRS Types::Dist/ ) {
-    use_module $mod;
-    my @mod_types = $mod->type_names;
-    $mod->import( @mod_types );
-    push @types, @mod_types;
-}
-
-our @EXPORT_OK = @types;
+Type::Utils::extends(qw/Types::OTRS Types::Dist/);
 
 1;
 
@@ -38,7 +28,7 @@ Types::RENEEB - Several predefined Type::Tiny types
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
